%-------------------------------------------------------------------------------
% Pink Noise Filter Calculator
% 
% Calculates coefficients and gains for a series of one-pole low-pass filters
% 
% Cooper Baker - 2015
% www.cooperbaker.com/home/code/pink noise
%-------------------------------------------------------------------------------

% sample rate
%------------
sr = 44100;
%------------

% variables
%-------------------------------------------------------------------------------
tpi = 2 * pi;
hz  = ( sr / tpi ) - 1;
i   = 0;
db  = 0;
s   = 0;
og  = 0;
p   = zeros( 8, 3 );

% calculate freqs and coeffs
%-------------------------------------------------------------------------------
while( hz > 1 )
   a = ( tpi * hz ) / sr;

   p( i + 1, 1 ) = hz;
   p( i + 1, 2 ) = a;
   
   hz = hz / 4;
   i = i + 1;
end

% calculate gains
%-------------------------------------------------------------------------------
while ( i > 0 )
    g = 10 ^ ( db / 20 );
    p( i , 3 ) = g;
    s = s + g;
    db = db - 6;
    
    i = i - 1;
end

og = 10 ^ ( ( -20 * log10( s ) ) / 20 );

% print results to console
%-------------------------------------------------------------------------------
p = flipud( p );
i = 1;

fprintf( '\n' );
fprintf( 'Sample Rate: %i Hz\n',    sr );
fprintf( 'Output Gain: %1.9f\n\n', og );
fprintf( 'freq\t\tcoef\t\tgain\t\t\n' );
fprintf( '------------------------------------------------\n' );

while( i < size( p, 1 ) + 1 )
    fprintf( '%1.9f\t%1.9f\t%1.9f \n', p(i,1), p(i,2), p(i,3) );
    i = i + 1;
end
